@@ -1,7 +1,7 @@
 // qjackctlConnect.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -442,6 +442,9 @@ public slots:
 	bool disconnectSelected();
 	bool disconnectAll();
 
+	// Expand all client ports.
+	void expandAll();
+
 	// Complete/incremental contents rebuilder; check dirty status if incremental.
 	void updateContents(bool bClear);
 
