@@ -1,7 +1,7 @@
 // qjackctlConnectionsForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -44,12 +44,20 @@ qjackctlConnectionsForm::qjackctlConnectionsForm (
 	// Setup UI struct...
 	m_ui.setupUi(this);
 
-	m_pJackClient   = NULL;
-	m_pAudioConnect = NULL;
-	m_pMidiConnect  = NULL;
+	m_pAudioConnect = new qjackctlJackConnect(
+		m_ui.AudioConnectView, QJACKCTL_JACK_AUDIO);
+#ifdef CONFIG_JACK_MIDI
+	m_pMidiConnect = new qjackctlJackConnect(
+		m_ui.MidiConnectView, QJACKCTL_JACK_MIDI);
+#else
+	m_pMidiConnect = NULL;
+#endif
 
-	m_pAlsaSeq      = NULL;
-	m_pAlsaConnect  = NULL;
+#ifdef CONFIG_ALSA_SEQ
+	m_pAlsaConnect = new qjackctlAlsaConnect(m_ui.AlsaConnectView);
+#else
+	m_pAlsaConnect = NULL;
+#endif
 
 	m_pSetup = NULL;
 
@@ -64,6 +72,9 @@ qjackctlConnectionsForm::qjackctlConnectionsForm (
 	QObject::connect(m_ui.AudioDisconnectAllPushButton,
 		SIGNAL(clicked()),
 		SLOT(audioDisconnectAll()));
+	QObject::connect(m_ui.AudioExpandAllPushButton,
+		SIGNAL(clicked()),
+		SLOT(audioExpandAll()));
 	QObject::connect(m_ui.AudioRefreshPushButton,
 		SIGNAL(clicked()),
 		SLOT(audioRefresh()));
@@ -77,6 +88,9 @@ qjackctlConnectionsForm::qjackctlConnectionsForm (
 	QObject::connect(m_ui.MidiDisconnectAllPushButton,
 		SIGNAL(clicked()),
 		SLOT(midiDisconnectAll()));
+	QObject::connect(m_ui.MidiExpandAllPushButton,
+		SIGNAL(clicked()),
+		SLOT(midiExpandAll()));
 	QObject::connect(m_ui.MidiRefreshPushButton,
 		SIGNAL(clicked()),
 		SLOT(midiRefresh()));
@@ -90,6 +104,9 @@ qjackctlConnectionsForm::qjackctlConnectionsForm (
 	QObject::connect(m_ui.AlsaDisconnectAllPushButton,
 		SIGNAL(clicked()),
 		SLOT(alsaDisconnectAll()));
+	QObject::connect(m_ui.AlsaExpandAllPushButton,
+		SIGNAL(clicked()),
+		SLOT(alsaExpandAll()));
 	QObject::connect(m_ui.AlsaRefreshPushButton,
 		SIGNAL(clicked()),
 		SLOT(alsaRefresh()));
@@ -125,6 +142,21 @@ qjackctlConnectionsForm::qjackctlConnectionsForm (
 		SIGNAL(contentsChanged()),
 		SLOT(alsaRefresh()));
 
+	// Actual connections...
+	QObject::connect(m_pAudioConnect,
+		SIGNAL(disconnecting(qjackctlPortItem *, qjackctlPortItem *)),
+		SLOT(audioDisconnecting(qjackctlPortItem *, qjackctlPortItem *)));
+#ifdef CONFIG_JACK_MIDI
+	QObject::connect(m_pMidiConnect,
+		SIGNAL(disconnecting(qjackctlPortItem *, qjackctlPortItem *)),
+		SLOT(midiDisconnecting(qjackctlPortItem *, qjackctlPortItem *)));
+#endif
+#ifdef CONFIG_ALSA_SEQ
+	QObject::connect(m_pAlsaConnect,
+		SIGNAL(disconnecting(qjackctlPortItem *, qjackctlPortItem *)),
+		SLOT(alsaDisconnecting(qjackctlPortItem *, qjackctlPortItem *)));
+#endif
+
 #ifndef CONFIG_JACK_MIDI
 	m_ui.ConnectionsTabWidget->setTabEnabled(1, false);
 #endif
@@ -132,6 +164,11 @@ qjackctlConnectionsForm::qjackctlConnectionsForm (
 //	m_ui.ConnectionsTabWidget->setTabEnabled(2, false);
 	m_ui.ConnectionsTabWidget->removeTab(2);
 #endif
+
+	// Start disabled.
+	stabilizeAudio(false);
+	stabilizeMidi(false);
+	stabilizeAlsa(false);
 }
 
 
@@ -139,8 +176,16 @@ qjackctlConnectionsForm::qjackctlConnectionsForm (
 qjackctlConnectionsForm::~qjackctlConnectionsForm (void)
 {
 	// Destroy our connections view...
-	setJackClient(NULL);
-	setAlsaSeq(NULL);
+	if (m_pAudioConnect)
+		delete m_pAudioConnect;
+#ifdef CONFIG_JACK_MIDI
+	if (m_pMidiConnect)
+		delete m_pMidiConnect;
+#endif
+#ifdef CONFIG_ALSA_SEQ
+	if (m_pAlsaConnect)
+		delete m_pAlsaConnect;
+#endif
 }
 
 
@@ -187,6 +232,20 @@ void qjackctlConnectionsForm::setup ( qjackctlSetup *pSetup )
 {
 	m_pSetup = pSetup;
 
+	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+	if (pMainForm) {
+		QObject::connect(m_pAudioConnect, SIGNAL(connectChanged()),
+			pMainForm, SLOT(jackConnectChanged()));
+	#ifdef CONFIG_JACK_MIDI
+		QObject::connect(m_pMidiConnect, SIGNAL(connectChanged()),
+			pMainForm, SLOT(jackConnectChanged()));
+	#endif
+	#ifdef CONFIG_ALSA_SEQ
+		QObject::connect(m_pAlsaConnect, SIGNAL(connectChanged()),
+			pMainForm, SLOT(alsaConnectChanged()));
+	#endif
+	}
+
 	// Load some splitter sizes...
 	if (m_pSetup) {
 		QList<int> sizes;
@@ -196,12 +255,12 @@ void qjackctlConnectionsForm::setup ( qjackctlSetup *pSetup )
 		m_pSetup->loadSplitterSizes(m_ui.AudioConnectView, sizes);
 		m_pSetup->loadSplitterSizes(m_ui.MidiConnectView, sizes);
 		m_pSetup->loadSplitterSizes(m_ui.AlsaConnectView, sizes);
-#ifdef CONFIG_ALSA_SEQ
+	#ifdef CONFIG_ALSA_SEQ
 		if (!m_pSetup->bAlsaSeqEnabled) {
 		//	m_ui.ConnectionsTabWidget->setTabEnabled(2, false);
 			m_ui.ConnectionsTabWidget->removeTab(2);
 		}
-#endif
+	#endif
 	}
 
 	// Update initial client/port aliases...
@@ -301,6 +360,18 @@ bool qjackctlConnectionsForm::saveAliases (void)
 }
 
 
+// Tab page accessors.
+void qjackctlConnectionsForm::setTabPage ( int iTabPage )
+{
+	m_ui.ConnectionsTabWidget->setCurrentIndex(iTabPage);
+}
+
+int qjackctlConnectionsForm::tabPage (void) const
+{
+	return m_ui.ConnectionsTabWidget->currentIndex();
+}
+
+
 // Connections view font accessors.
 QFont qjackctlConnectionsForm::connectionsFont (void) const
 {
@@ -330,75 +401,6 @@ void qjackctlConnectionsForm::setConnectionsIconSize ( int iIconSize )
 }
 
 
-// (Un)Bind a JACK client to this form.
-void qjackctlConnectionsForm::setJackClient ( jack_client_t *pJackClient )
-{
-	m_pJackClient = pJackClient;
-
-	if (pJackClient == NULL) {
-		if (m_pAudioConnect) {
-			delete m_pAudioConnect;
-			m_pAudioConnect = NULL;
-		}
-		if (m_pMidiConnect) {
-			delete m_pMidiConnect;
-			m_pMidiConnect = NULL;
-		}
-	}
-
-	if (pJackClient) {
-		qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-		if (m_pAudioConnect == NULL && pMainForm) {
-			m_pAudioConnect = new qjackctlJackConnect(
-				m_ui.AudioConnectView, pJackClient, QJACKCTL_JACK_AUDIO);
-			QObject::connect(m_pAudioConnect, SIGNAL(connectChanged()),
-				pMainForm, SLOT(jackConnectChanged()));
-			QObject::connect(m_pAudioConnect,
-				SIGNAL(disconnecting(qjackctlPortItem *, qjackctlPortItem *)),
-				SLOT(audioDisconnecting(qjackctlPortItem *, qjackctlPortItem *)));
-		}
-		if (m_pMidiConnect == NULL && pMainForm) {
-			m_pMidiConnect = new qjackctlJackConnect(
-				m_ui.MidiConnectView, pJackClient, QJACKCTL_JACK_MIDI);
-			QObject::connect(m_pMidiConnect, SIGNAL(connectChanged()),
-				pMainForm, SLOT(jackConnectChanged()));
-			QObject::connect(m_pMidiConnect,
-				SIGNAL(disconnecting(qjackctlPortItem *, qjackctlPortItem *)),
-				SLOT(midiDisconnecting(qjackctlPortItem *, qjackctlPortItem *)));
-		}
-	}
-
-	stabilizeAudio(pJackClient != NULL);
-	stabilizeMidi(pJackClient != NULL);
-}
-
-
-// (Un)Bind a ALSA sequencer descriptor to this form.
-void qjackctlConnectionsForm::setAlsaSeq ( snd_seq_t *pAlsaSeq )
-{
-	m_pAlsaSeq = pAlsaSeq;
-
-	if (pAlsaSeq == NULL && m_pAlsaConnect) {
-		delete m_pAlsaConnect;
-		m_pAlsaConnect = NULL;
-	}
-
-	if (pAlsaSeq && m_pAlsaConnect == NULL) {
-		qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-		m_pAlsaConnect = new qjackctlAlsaConnect(m_ui.AlsaConnectView, pAlsaSeq);
-		if (pMainForm) {
-			QObject::connect(m_pAlsaConnect, SIGNAL(connectChanged()),
-				pMainForm, SLOT(alsaConnectChanged()));
-			QObject::connect(m_pAlsaConnect,
-				SIGNAL(disconnecting(qjackctlPortItem *, qjackctlPortItem *)),
-				SLOT(alsaDisconnecting(qjackctlPortItem *, qjackctlPortItem *)));
-		}
-	}
-
-	stabilizeAlsa(pAlsaSeq != NULL);
-}
-
-
 // Check if there's JACK audio connections.
 bool qjackctlConnectionsForm::isAudioConnected (void) const
 {
@@ -441,6 +443,16 @@ void qjackctlConnectionsForm::audioDisconnectAll (void)
 }
 
 
+// Expand all JACK audio client ports.
+void qjackctlConnectionsForm::audioExpandAll (void)
+{
+	if (m_pAudioConnect) {
+		m_pAudioConnect->expandAll();
+		stabilizeAudio(true);
+	}
+}
+
+
 // JACK audio ports disconnecting.
 void qjackctlConnectionsForm::audioDisconnecting (
 	qjackctlPortItem *pOPort, qjackctlPortItem *pIPort )
@@ -507,6 +519,16 @@ void qjackctlConnectionsForm::midiDisconnectAll (void)
 }
 
 
+// Expand all JACK MIDI client ports.
+void qjackctlConnectionsForm::midiExpandAll (void)
+{
+	if (m_pMidiConnect) {
+		m_pMidiConnect->expandAll();
+		stabilizeMidi(true);
+	}
+}
+
+
 // JACK MIDI ports disconnecting.
 void qjackctlConnectionsForm::midiDisconnecting (
 	qjackctlPortItem *pOPort, qjackctlPortItem *pIPort )
@@ -573,6 +595,16 @@ void qjackctlConnectionsForm::alsaDisconnectAll (void)
 }
 
 
+// Expand all ALSA MIDI client ports.
+void qjackctlConnectionsForm::alsaExpandAll (void)
+{
+	if (m_pAlsaConnect) {
+		m_pAlsaConnect->expandAll();
+		stabilizeAlsa(true);
+	}
+}
+
+
 // ALSA MIDI ports disconnecting.
 void qjackctlConnectionsForm::alsaDisconnecting (
 	qjackctlPortItem *pOPort, qjackctlPortItem *pIPort )
@@ -605,7 +637,7 @@ void qjackctlConnectionsForm::refreshAudio ( bool bEnabled )
 		return;
 
 	if (bEnabled) {
-		m_pAudioConnect->refresh();
+	//	m_pAudioConnect->refresh();
 		stabilizeAudio(true);
 	} else {
 		qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
@@ -620,7 +652,7 @@ void qjackctlConnectionsForm::refreshMidi ( bool bEnabled )
 		return;
 
 	if (bEnabled) {
-		m_pMidiConnect->refresh();
+	//	m_pMidiConnect->refresh();
 		stabilizeMidi(true);
 	} else {
 		qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
@@ -635,7 +667,7 @@ void qjackctlConnectionsForm::refreshAlsa ( bool bEnabled )
 		return;
 
 	if (bEnabled) {
-		m_pAlsaConnect->refresh();
+	//	m_pAlsaConnect->refresh();
 		stabilizeAlsa(true);
 	} else {
 		qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
@@ -648,6 +680,9 @@ void qjackctlConnectionsForm::refreshAlsa ( bool bEnabled )
 // Proper enablement of connections command controls.
 void qjackctlConnectionsForm::stabilizeAudio ( bool bEnabled )
 {
+	if (m_pAudioConnect)
+		m_pAudioConnect->updateContents(!bEnabled);
+
 	if (m_pAudioConnect && bEnabled) {
 		m_ui.AudioConnectPushButton->setEnabled(
 			m_pAudioConnect->canConnectSelected());
@@ -655,17 +690,22 @@ void qjackctlConnectionsForm::stabilizeAudio ( bool bEnabled )
 			m_pAudioConnect->canDisconnectSelected());
 		m_ui.AudioDisconnectAllPushButton->setEnabled(
 			m_pAudioConnect->canDisconnectAll());
+		m_ui.AudioExpandAllPushButton->setEnabled(true);
 		m_ui.AudioRefreshPushButton->setEnabled(true);
 	} else {
 		m_ui.AudioConnectPushButton->setEnabled(false);
 		m_ui.AudioDisconnectPushButton->setEnabled(false);
 		m_ui.AudioDisconnectAllPushButton->setEnabled(false);
+		m_ui.AudioExpandAllPushButton->setEnabled(false);
 		m_ui.AudioRefreshPushButton->setEnabled(false);
 	}
 }
 
 void qjackctlConnectionsForm::stabilizeMidi ( bool bEnabled )
 {
+	if (m_pMidiConnect)
+		m_pMidiConnect->updateContents(!bEnabled);
+
 	if (m_pMidiConnect && bEnabled) {
 		m_ui.MidiConnectPushButton->setEnabled(
 			m_pMidiConnect->canConnectSelected());
@@ -673,26 +713,36 @@ void qjackctlConnectionsForm::stabilizeMidi ( bool bEnabled )
 			m_pMidiConnect->canDisconnectSelected());
 		m_ui.MidiDisconnectAllPushButton->setEnabled(
 			m_pMidiConnect->canDisconnectAll());
+		m_ui.MidiExpandAllPushButton->setEnabled(true);
 		m_ui.MidiRefreshPushButton->setEnabled(true);
 	} else {
 		m_ui.MidiConnectPushButton->setEnabled(false);
 		m_ui.MidiDisconnectPushButton->setEnabled(false);
 		m_ui.MidiDisconnectAllPushButton->setEnabled(false);
+		m_ui.MidiExpandAllPushButton->setEnabled(false);
 		m_ui.MidiRefreshPushButton->setEnabled(false);
 	}
 }
 
 void qjackctlConnectionsForm::stabilizeAlsa ( bool bEnabled )
 {
+	if (m_pAlsaConnect)
+		m_pAlsaConnect->updateContents(!bEnabled);
+
 	if (m_pAlsaConnect && bEnabled) {
-		m_ui.AlsaConnectPushButton->setEnabled(m_pAlsaConnect->canConnectSelected());
-		m_ui.AlsaDisconnectPushButton->setEnabled(m_pAlsaConnect->canDisconnectSelected());
-		m_ui.AlsaDisconnectAllPushButton->setEnabled(m_pAlsaConnect->canDisconnectAll());
+		m_ui.AlsaConnectPushButton->setEnabled(
+			m_pAlsaConnect->canConnectSelected());
+		m_ui.AlsaDisconnectPushButton->setEnabled(
+			m_pAlsaConnect->canDisconnectSelected());
+		m_ui.AlsaDisconnectAllPushButton->setEnabled(
+			m_pAlsaConnect->canDisconnectAll());
+		m_ui.AlsaExpandAllPushButton->setEnabled(true);
 		m_ui.AlsaRefreshPushButton->setEnabled(true);
 	} else {
 		m_ui.AlsaConnectPushButton->setEnabled(false);
 		m_ui.AlsaDisconnectPushButton->setEnabled(false);
 		m_ui.AlsaDisconnectAllPushButton->setEnabled(false);
+		m_ui.AlsaExpandAllPushButton->setEnabled(false);
 		m_ui.AlsaRefreshPushButton->setEnabled(false);
 	}
 }
