@@ -1,7 +1,7 @@
 // qjackctlConnectionsForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -53,14 +53,16 @@ public:
 
 	bool queryClose();
 
+	enum TabPage { AudioTab = 0, MidiTab = 1, AlsaTab = 2 };
+
+	void setTabPage(int iTabPage);
+	int tabPage() const;
+
 	QFont connectionsFont() const;
 	void setConnectionsFont(const QFont& font);
 
 	void setConnectionsIconSize(int iIconSize);
 
-	void setJackClient(jack_client_t * pJackClient);
-	void setAlsaSeq(snd_seq_t * pAlsaSeq);
-
 	bool isAudioConnected() const;
 	bool isMidiConnected() const;
 	bool isAlsaConnected() const;
@@ -83,18 +85,21 @@ public slots:
 	void audioConnectSelected();
 	void audioDisconnectSelected();
 	void audioDisconnectAll();
+	void audioExpandAll();
 	void audioRefresh();
 	void audioStabilize();
 
 	void midiConnectSelected();
 	void midiDisconnectSelected();
 	void midiDisconnectAll();
+	void midiExpandAll();
 	void midiRefresh();
 	void midiStabilize();
 
 	void alsaConnectSelected();
 	void alsaDisconnectSelected();
 	void alsaDisconnectAll();
+	void alsaExpandAll();
 	void alsaRefresh();
 	void alsaStabilize();
 
@@ -118,8 +123,6 @@ private:
 	Ui::qjackctlConnectionsForm m_ui;
 
 	// Instance variables.
-	jack_client_t       *m_pJackClient;
-	snd_seq_t           *m_pAlsaSeq;
 	qjackctlJackConnect *m_pAudioConnect;
 	qjackctlJackConnect *m_pMidiConnect;
 	qjackctlAlsaConnect *m_pAlsaConnect;
