@@ -40,8 +40,8 @@ typedef void snd_seq_t;
 
 // Forward declarations.
 class qjackctlSetup;
-class qjackctlMessagesForm;
-class qjackctlStatusForm;
+class qjackctlMessagesStatusForm;
+class qjackctlSessionForm;
 class qjackctlConnectionsForm;
 class qjackctlPatchbayForm;
 class qjackctlPatchbayRack;
@@ -74,6 +74,11 @@ public:
 
 	bool setup(qjackctlSetup * pSetup);
 
+	jack_client_t *jackClient() const;
+	snd_seq_t *alsaSeq() const;
+
+	void appendMessages(const QString& s);
+
 	bool isActivePatchbay(const QString& sPatchbayPath) const;
 	void updateActivePatchbay();
 	void setActivePatchbay(const QString& sPatchbayPath);
@@ -98,14 +103,17 @@ public slots:
 	void startJack();
 	void stopJack();
 
+	void resetXrunStats();
+
+protected slots:
+
 	void readStdout();
-	void appendStdoutBuffer(const QString&);
-	void flushStdoutBuffer();
 
 	void jackStarted();
 	void jackError(QProcess::ProcessError);
 	void jackFinished();
 	void jackCleanup();
+	void jackStabilize();
 
 	void stdoutNotifySlot(int);
 	void alsaNotifySlot(int);
@@ -118,8 +126,10 @@ public slots:
 	void cableConnectSlot(const QString&, const QString&, unsigned int);
 
 	void toggleMainForm();
+	void toggleMessagesStatusForm();
 	void toggleMessagesForm();
 	void toggleStatusForm();
+	void toggleSessionForm();
 	void toggleConnectionsForm();
 	void togglePatchbayForm();
 
@@ -135,8 +145,8 @@ public slots:
 
 	void systemTrayContextMenu(const QPoint&);
 	void activatePresetsMenu(QAction *);
-
-	void resetXrunStats();
+	void activatePreset(const QString&);
+	void activatePreset(int);
 
 	void quitMainForm();
 
@@ -147,6 +157,9 @@ protected:
 	void closeEvent(QCloseEvent * pCloseEvent);
 	void customEvent(QEvent *pEvent);
 
+	void appendStdoutBuffer(const QString&);
+	void flushStdoutBuffer();
+
 	QString formatExitStatus(int iExitStatus) const;
 
 	void shellExecute(const QString& sShellCommand,
@@ -157,7 +170,6 @@ protected:
 	QString& detectXrun(QString& s);
 	void updateXrunStats(float fXrunLast);
 
-	void appendMessages(const QString& s);
 	void appendMessagesColor(const QString& s, const QString& c);
 	void appendMessagesText(const QString& s);
 	void appendMessagesError(const QString& s);
@@ -231,6 +243,12 @@ protected:
 
 #endif
 
+	// Quotes string with embedded whitespace.
+	QString formatQuoted(const QString& s) const;
+
+	// Guarded transport play/pause toggle.
+	void transportPlayStatus(bool bOn);
+
 private:
 
 	// The Qt-designer UI struct...
@@ -281,8 +299,8 @@ private:
 	QTime m_tXrunLast;
 	QTime m_tResetLast;
 
-	qjackctlMessagesForm    *m_pMessagesForm;
-	qjackctlStatusForm      *m_pStatusForm;
+	qjackctlMessagesStatusForm *m_pMessagesStatusForm;
+	qjackctlSessionForm     *m_pSessionForm;
 	qjackctlConnectionsForm *m_pConnectionsForm;
 	qjackctlPatchbayForm    *m_pPatchbayForm;
 
@@ -299,6 +317,8 @@ private:
 	bool  m_bQuitForce;
 	float m_fSkipAccel;
 
+	int m_iTransportPlay;
+
 	// Kind-of singleton reference.
 	static qjackctlMainForm *g_pMainForm;
 };
