@@ -1,7 +1,7 @@
 // qjackctlPatchbay.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -21,6 +21,8 @@
 
 #include "qjackctlPatchbay.h"
 
+#include "qjackctlMainForm.h"
+
 #include <QMessageBox>
 #include <QHeaderView>
 #include <QPainterPath>
@@ -318,33 +320,31 @@ bool qjackctlSocketItem::isOpen (void) const
 qjackctlSocketList::qjackctlSocketList (
 	qjackctlSocketListView *pListView, bool bReadable )
 {
-	QPixmap pmXSocket1(":/icons/xsocket1.png");
+	QPixmap pmXSocket1(":/images/xsocket1.png");
 
-	m_pListView   = pListView;
-	m_bReadable   = bReadable;
-	m_pJackClient = NULL;
-	m_pAlsaSeq    = NULL;
+	m_pListView = pListView;
+	m_bReadable = bReadable;
 
 	if (bReadable) {
 		m_sSocketCaption = tr("Output");
-		m_apPixmaps[QJACKCTL_XPM_AUDIO_SOCKET]   = new QPixmap(":/icons/asocketo.png");
+		m_apPixmaps[QJACKCTL_XPM_AUDIO_SOCKET]   = new QPixmap(":/images/asocketo.png");
 		m_apPixmaps[QJACKCTL_XPM_AUDIO_SOCKET_X] = createPixmapMerge(*m_apPixmaps[QJACKCTL_XPM_AUDIO_SOCKET], pmXSocket1);
-		m_apPixmaps[QJACKCTL_XPM_AUDIO_CLIENT]   = new QPixmap(":/icons/acliento.png");
-		m_apPixmaps[QJACKCTL_XPM_AUDIO_PLUG]     = new QPixmap(":/icons/aportlno.png");
-		m_apPixmaps[QJACKCTL_XPM_MIDI_SOCKET]    = new QPixmap(":/icons/msocketo.png");
+		m_apPixmaps[QJACKCTL_XPM_AUDIO_CLIENT]   = new QPixmap(":/images/acliento.png");
+		m_apPixmaps[QJACKCTL_XPM_AUDIO_PLUG]     = new QPixmap(":/images/aportlno.png");
+		m_apPixmaps[QJACKCTL_XPM_MIDI_SOCKET]    = new QPixmap(":/images/msocketo.png");
 		m_apPixmaps[QJACKCTL_XPM_MIDI_SOCKET_X]  = createPixmapMerge(*m_apPixmaps[QJACKCTL_XPM_MIDI_SOCKET], pmXSocket1);
-		m_apPixmaps[QJACKCTL_XPM_MIDI_CLIENT]    = new QPixmap(":/icons/mcliento.png");
-		m_apPixmaps[QJACKCTL_XPM_MIDI_PLUG]      = new QPixmap(":/icons/mporto.png");
+		m_apPixmaps[QJACKCTL_XPM_MIDI_CLIENT]    = new QPixmap(":/images/mcliento.png");
+		m_apPixmaps[QJACKCTL_XPM_MIDI_PLUG]      = new QPixmap(":/images/mporto.png");
 	} else {
 		m_sSocketCaption = tr("Input");
-		m_apPixmaps[QJACKCTL_XPM_AUDIO_SOCKET]   = new QPixmap(":/icons/asocketi.png");
+		m_apPixmaps[QJACKCTL_XPM_AUDIO_SOCKET]   = new QPixmap(":/images/asocketi.png");
 		m_apPixmaps[QJACKCTL_XPM_AUDIO_SOCKET_X] = createPixmapMerge(*m_apPixmaps[QJACKCTL_XPM_AUDIO_SOCKET], pmXSocket1);
-		m_apPixmaps[QJACKCTL_XPM_AUDIO_CLIENT]   = new QPixmap(":/icons/aclienti.png");
-		m_apPixmaps[QJACKCTL_XPM_AUDIO_PLUG]     = new QPixmap(":/icons/aportlni.png");
-		m_apPixmaps[QJACKCTL_XPM_MIDI_SOCKET]    = new QPixmap(":/icons/msocketi.png");
+		m_apPixmaps[QJACKCTL_XPM_AUDIO_CLIENT]   = new QPixmap(":/images/aclienti.png");
+		m_apPixmaps[QJACKCTL_XPM_AUDIO_PLUG]     = new QPixmap(":/images/aportlni.png");
+		m_apPixmaps[QJACKCTL_XPM_MIDI_SOCKET]    = new QPixmap(":/images/msocketi.png");
 		m_apPixmaps[QJACKCTL_XPM_MIDI_SOCKET_X]  = createPixmapMerge(*m_apPixmaps[QJACKCTL_XPM_MIDI_SOCKET], pmXSocket1);
-		m_apPixmaps[QJACKCTL_XPM_MIDI_CLIENT]    = new QPixmap(":/icons/mclienti.png");
-		m_apPixmaps[QJACKCTL_XPM_MIDI_PLUG]      = new QPixmap(":/icons/mporti.png");
+		m_apPixmaps[QJACKCTL_XPM_MIDI_CLIENT]    = new QPixmap(":/images/mclienti.png");
+		m_apPixmaps[QJACKCTL_XPM_MIDI_PLUG]      = new QPixmap(":/images/mporti.png");
 	}
 
 	if (!m_sSocketCaption.isEmpty())
@@ -406,30 +406,6 @@ const QString& qjackctlSocketList::socketCaption (void) const
 }
 
 
-// JACK client accessors.
-void qjackctlSocketList::setJackClient ( jack_client_t *pJackClient )
-{
-	m_pJackClient = pJackClient;
-}
-
-jack_client_t *qjackctlSocketList::jackClient (void) const
-{
-	return m_pJackClient;
-}
-
-
-// ALSA sequencer accessors.
-void qjackctlSocketList::setAlsaSeq ( snd_seq_t *pAlsaSeq )
-{
-	m_pAlsaSeq = pAlsaSeq;
-}
-
-snd_seq_t *qjackctlSocketList::alsaSeq (void) const
-{
-	return m_pAlsaSeq;
-}
-
-
 // Socket list cleaner.
 void qjackctlSocketList::clear (void)
 {
@@ -488,8 +464,7 @@ bool qjackctlSocketList::addSocketItem (void)
 	socketForm.setSocketCaption(m_sSocketCaption);
 	socketForm.setPixmaps(m_apPixmaps);
 	socketForm.setSocketList(this);
-	socketForm.setJackClient(m_pJackClient);
-	socketForm.setAlsaSeq(m_pAlsaSeq);
+	socketForm.setSocketNew(true);
 	qjackctlPatchbaySocket socket(m_sSocketCaption
 		+ ' ' + QString::number(m_sockets.count() + 1),
 		QString::null, QJACKCTL_SOCKETTYPE_JACK_AUDIO);
@@ -499,11 +474,11 @@ bool qjackctlSocketList::addSocketItem (void)
 		qjackctlSocketItem *pSocketItem = selectedSocketItem();
 	//  m_pListView->setUpdatesEnabled(false);
 		if (pSocketItem)
-#if QT_VERSION >= 0x040200
+		#if QT_VERSION >= 0x040200
 			pSocketItem->setSelected(false);
-#else
+		#else
 			m_pListView->setItemSelected(pSocketItem, false);
-#endif
+		#endif
 		pSocketItem = new qjackctlSocketItem(this, socket.name(),
 			socket.clientName(), socket.type(), pSocketItem);
 		if (pSocketItem) {
@@ -517,11 +492,11 @@ bool qjackctlSocketList::addSocketItem (void)
 			}
 			bResult = true;
 		}
-#if QT_VERSION >= 0x040200
+	#if QT_VERSION >= 0x040200
 		pSocketItem->setSelected(true);
-#else
+	#else
 		m_pListView->setItemSelected(pSocketItem, true);
-#endif
+	#endif
 		m_pListView->setCurrentItem(pSocketItem);
 	//  m_pListView->setUpdatesEnabled(true);
 	//  m_pListView->update();
@@ -569,8 +544,7 @@ bool qjackctlSocketList::editSocketItem (void)
 		socketForm.setSocketCaption(m_sSocketCaption);
 		socketForm.setPixmaps(m_apPixmaps);
 		socketForm.setSocketList(this);
-		socketForm.setJackClient(m_pJackClient);
-		socketForm.setAlsaSeq(m_pAlsaSeq);
+		socketForm.setSocketNew(false);
 		qjackctlPatchbaySocket socket(pSocketItem->socketName(),
 			pSocketItem->clientName(), pSocketItem->socketType());
 		socket.setExclusive(pSocketItem->isExclusive());
@@ -597,11 +571,11 @@ bool qjackctlSocketList::editSocketItem (void)
 				pPlugItem = new qjackctlPlugItem(
 					pSocketItem, iter.next(), pPlugItem);
 			}
-#if QT_VERSION >= 0x040200
+		#if QT_VERSION >= 0x040200
 			pSocketItem->setSelected(true);
-#else
+		#else
 			m_pListView->setItemSelected(pSocketItem, true);
-#endif
+		#endif
 			m_pListView->setCurrentItem(pSocketItem);
 		//  m_pListView->setUpdatesEnabled(true);
 		//  m_pListView->triggerUpdate();
@@ -636,8 +610,7 @@ bool qjackctlSocketList::copySocketItem (void)
 		socketForm.setSocketCaption(m_sSocketCaption);
 		socketForm.setPixmaps(m_apPixmaps);
 		socketForm.setSocketList(this);
-		socketForm.setJackClient(m_pJackClient);
-		socketForm.setAlsaSeq(m_pAlsaSeq);
+		socketForm.setSocketNew(true);
 		qjackctlPatchbaySocket socket(sSocketName,
 			pSocketItem->clientName(), iSocketType);
 		if (pSocketItem->isExclusive())
@@ -661,11 +634,11 @@ bool qjackctlSocketList::copySocketItem (void)
 				}
 				bResult = true;
 			}
-#if QT_VERSION >= 0x040200
+		#if QT_VERSION >= 0x040200
 			pSocketItem->setSelected(true);
-#else
+		#else
 			m_pListView->setItemSelected(pSocketItem, true);
-#endif
+		#endif
 			m_pListView->setCurrentItem(pSocketItem);
 		//  m_pListView->setUpdatesEnabled(true);
 		//  m_pListView->triggerUpdate();
@@ -706,11 +679,11 @@ bool qjackctlSocketList::moveUpSocketItem (void)
 			QTreeWidgetItem *pItem = m_pListView->takeTopLevelItem(iItem);
 			if (pItem) {
 				m_pListView->insertTopLevelItem(iItem - 1, pItem);
-#if QT_VERSION >= 0x040200
+			#if QT_VERSION >= 0x040200
 				pSocketItem->setSelected(true);
-#else
+			#else
 				m_pListView->setItemSelected(pSocketItem, true);
-#endif
+			#endif
 				m_pListView->setCurrentItem(pSocketItem);
 			//  m_pListView->setUpdatesEnabled(true);
 			//  m_pListView->update();
@@ -737,11 +710,11 @@ bool qjackctlSocketList::moveDownSocketItem (void)
 			QTreeWidgetItem *pItem = m_pListView->takeTopLevelItem(iItem);
 			if (pItem) {
 				m_pListView->insertTopLevelItem(iItem + 1, pItem);
-#if QT_VERSION >= 0x040200
+			#if QT_VERSION >= 0x040200
 				pSocketItem->setSelected(true);
-#else
+			#else
 				m_pListView->setItemSelected(pSocketItem, true);
-#endif
+			#endif
 				m_pListView->setCurrentItem(pSocketItem);
 			//  m_pListView->setUpdatesEnabled(true);
 			//  m_pListView->update();
@@ -1276,15 +1249,15 @@ void qjackctlPatchbayView::contextMenu ( const QPoint& pos,
 	if (pSocketList) {
 		qjackctlSocketItem *pSocketItem = pSocketList->selectedSocketItem();
 		bool bEnabled = (pSocketItem != NULL);
-		pAction = menu.addAction(QIcon(":/icons/add1.png"),
+		pAction = menu.addAction(QIcon(":/images/add1.png"),
 			tr("Add..."), pSocketList, SLOT(addSocketItem()));
-		pAction = menu.addAction(QIcon(":/icons/edit1.png"),
+		pAction = menu.addAction(QIcon(":/images/edit1.png"),
 			tr("Edit..."), pSocketList, SLOT(editSocketItem()));
 		pAction->setEnabled(bEnabled);
-		pAction = menu.addAction(QIcon(":/icons/copy1.png"),
+		pAction = menu.addAction(QIcon(":/images/copy1.png"),
 			tr("Copy..."), pSocketList, SLOT(copySocketItem()));
 		pAction->setEnabled(bEnabled);
-		pAction = menu.addAction(QIcon(":/icons/remove1.png"),
+		pAction = menu.addAction(QIcon(":/images/remove1.png"),
 			tr("Remove"), pSocketList, SLOT(removeSocketItem()));
 		pAction->setEnabled(bEnabled);
 		menu.addSeparator();
@@ -1347,30 +1320,30 @@ void qjackctlPatchbayView::contextMenu ( const QPoint& pos,
 		menu.addSeparator();
 		int iItem = (pSocketList->listView())->indexOfTopLevelItem(pSocketItem);
 		int iItemCount = (pSocketList->listView())->topLevelItemCount();
-		pAction = menu.addAction(QIcon(":/icons/up1.png"),
+		pAction = menu.addAction(QIcon(":/images/up1.png"),
 			tr("Move Up"), pSocketList, SLOT(moveUpSocketItem()));
 		pAction->setEnabled(bEnabled && iItem > 0);
-		pAction = menu.addAction(QIcon(":/icons/down1.png"),
+		pAction = menu.addAction(QIcon(":/images/down1.png"),
 			tr("Move Down"), pSocketList, SLOT(moveDownSocketItem()));
 		pAction->setEnabled(bEnabled && iItem < iItemCount - 1);
 		menu.addSeparator();
 	}
 
-	pAction = menu.addAction(QIcon(":/icons/connect1.png"),
+	pAction = menu.addAction(QIcon(":/images/connect1.png"),
 		tr("&Connect"), pPatchbay, SLOT(connectSelected()),
 		tr("Alt+C", "Connect"));
 	pAction->setEnabled(pPatchbay->canConnectSelected());
-	pAction = menu.addAction(QIcon(":/icons/disconnect1.png"),
+	pAction = menu.addAction(QIcon(":/images/disconnect1.png"),
 		tr("&Disconnect"), pPatchbay, SLOT(disconnectSelected()),
 		tr("Alt+D", "Disconnect"));
 	pAction->setEnabled(pPatchbay->canDisconnectSelected());
-	pAction = menu.addAction(QIcon(":/icons/disconnectall1.png"),
+	pAction = menu.addAction(QIcon(":/images/disconnectall1.png"),
 		tr("Disconnect &All"), pPatchbay, SLOT(disconnectAll()),
 		tr("Alt+A", "Disconect All"));
 	pAction->setEnabled(pPatchbay->canDisconnectAll());
 
 	menu.addSeparator();
-	pAction = menu.addAction(QIcon(":/icons/refresh1.png"),
+	pAction = menu.addAction(QIcon(":/images/refresh1.png"),
 		tr("&Refresh"), pPatchbay, SLOT(refresh()),
 		tr("Alt+R", "Refresh"));
 
@@ -1757,6 +1730,14 @@ bool qjackctlPatchbay::disconnectAll (void)
 }
 
 
+// Expand all socket items.
+void qjackctlPatchbay::expandAll (void)
+{
+	(m_pOSocketList->listView())->expandAll();
+	(m_pISocketList->listView())->expandAll();
+	(m_pPatchbayView->PatchworkView())->update();
+}
+
 
 // Complete contents rebuilder.
 void qjackctlPatchbay::refresh (void)
@@ -1929,37 +1910,16 @@ void qjackctlPatchbay::saveRack ( qjackctlPatchbayRack *pPatchbayRack )
 }
 
 
-// JACK client property accessors.
-void qjackctlPatchbay::setJackClient ( jack_client_t *pJackClient )
-{
-	m_pOSocketList->setJackClient(pJackClient);
-	m_pISocketList->setJackClient(pJackClient);
-}
-
-jack_client_t *qjackctlPatchbay::jackClient (void) const
-{
-	return m_pOSocketList->jackClient();
-}
-
-// ALSA sequencer property accessors.
-void qjackctlPatchbay::setAlsaSeq ( snd_seq_t *pAlsaSeq )
-{
-	m_pOSocketList->setAlsaSeq(pAlsaSeq);
-	m_pISocketList->setAlsaSeq(pAlsaSeq);
-}
-
-snd_seq_t *qjackctlPatchbay::alsaSeq (void) const
-{
-	return m_pOSocketList->alsaSeq();
-}
-
-
 // Connections snapshot.
 void qjackctlPatchbay::connectionsSnapshot (void)
 {
+	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+	if (pMainForm == NULL)
+		return;
+
 	qjackctlPatchbayRack rack;
-	rack.connectJackSnapshot(jackClient());
-	rack.connectAlsaSnapshot(alsaSeq());
+	rack.connectJackSnapshot(pMainForm->jackClient());
+	rack.connectAlsaSnapshot(pMainForm->alsaSeq());
 	loadRack(&rack);
 
 	// Set dirty flag.
