@@ -1,7 +1,7 @@
 // qjackctlPatchbayForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -26,7 +26,6 @@
 #include "qjackctlSetup.h"
 
 #include "qjackctlMainForm.h"
-#include "qjackctlSocketForm.h"
 
 #include <QMessageBox>
 #include <QFileDialog>
@@ -124,6 +123,10 @@ qjackctlPatchbayForm::qjackctlPatchbayForm (
 		SIGNAL(clicked()),
 		SLOT(disconnectAll()));
 
+	QObject::connect(m_ui.ExpandAllPushButton,
+		SIGNAL(clicked()),
+		SLOT(expandAll()));
+
 	QObject::connect(m_ui.RefreshPushButton,
 		SIGNAL(clicked()),
 		SLOT(refreshForm()));
@@ -282,14 +285,18 @@ void qjackctlPatchbayForm::stabilizeForm ( void )
 	if (m_ui.PatchbayView->binding() == NULL)
 		return;
 
+	bool bExpandAll = false;
+
 	qjackctlSocketList *pSocketList;
 	qjackctlSocketItem *pSocketItem;
+	int iItemCount, iItem;
 
 	pSocketList = m_pPatchbay->OSocketList();
 	pSocketItem = pSocketList->selectedSocketItem();
+	iItemCount  = (pSocketList->listView())->topLevelItemCount();
+	bExpandAll  = bExpandAll || (iItemCount > 0);
 	if (pSocketItem) {
-		int iItem = (pSocketList->listView())->indexOfTopLevelItem(pSocketItem);
-		int iItemCount = (pSocketList->listView())->topLevelItemCount();
+		iItem = (pSocketList->listView())->indexOfTopLevelItem(pSocketItem);
 		m_ui.OSocketEditPushButton->setEnabled(true);
 		m_ui.OSocketCopyPushButton->setEnabled(true);
 		m_ui.OSocketRemovePushButton->setEnabled(true);
@@ -305,9 +312,10 @@ void qjackctlPatchbayForm::stabilizeForm ( void )
 
 	pSocketList = m_pPatchbay->ISocketList();
 	pSocketItem = pSocketList->selectedSocketItem();
+	iItemCount  = (pSocketList->listView())->topLevelItemCount();
+	bExpandAll  = bExpandAll || (iItemCount > 0);
 	if (pSocketItem) {
-		int iItem = (pSocketList->listView())->indexOfTopLevelItem(pSocketItem);
-		int iItemCount = (pSocketList->listView())->topLevelItemCount();
+		iItem = (pSocketList->listView())->indexOfTopLevelItem(pSocketItem);
 		m_ui.ISocketEditPushButton->setEnabled(true);
 		m_ui.ISocketCopyPushButton->setEnabled(true);
 		m_ui.ISocketRemovePushButton->setEnabled(true);
@@ -327,6 +335,7 @@ void qjackctlPatchbayForm::stabilizeForm ( void )
 		m_pPatchbay->canDisconnectSelected());
 	m_ui.DisconnectAllPushButton->setEnabled(
 		m_pPatchbay->canDisconnectAll());
+	m_ui.ExpandAllPushButton->setEnabled(bExpandAll);
 }
 
 
@@ -434,7 +443,8 @@ void qjackctlPatchbayForm::newPatchbay (void)
 	bool bSnapshot = false;
 
 	// Ask user what he/she wants to do...
-	if (m_pPatchbay->jackClient() || m_pPatchbay->alsaSeq()) {
+	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+	if (pMainForm && (pMainForm->jackClient() || pMainForm->alsaSeq())) {
 		switch (QMessageBox::information(this,
 			tr("New Patchbay definition") + " - " QJACKCTL_SUBTITLE1,
 			tr("Create patchbay definition as a snapshot\n"
@@ -566,7 +576,7 @@ void qjackctlPatchbayForm::updateRecentPatchbays (void)
 	m_iUpdate++;
 
 	// Update the visible combobox...
-	const QIcon icon(":/icons/patchbay1.png");
+	const QIcon icon(":/images/patchbay1.png");
 	m_ui.PatchbayComboBox->clear();
 
 	if (m_sPatchbayPath.isEmpty()) {
@@ -607,20 +617,6 @@ void qjackctlPatchbayForm::updateRecentPatchbays (void)
 }
 
 
-// (Un)Bind a JACK client to this form.
-void qjackctlPatchbayForm::setJackClient ( jack_client_t *pJackClient )
-{
-	m_pPatchbay->setJackClient(pJackClient);
-}
-
-
-// (Un)Bind a ALSA sequencer to this form.
-void qjackctlPatchbayForm::setAlsaSeq ( snd_seq_t *pAlsaSeq )
-{
-	m_pPatchbay->setAlsaSeq(pAlsaSeq);
-}
-
-
 // Output socket list push button handlers gallore...
 
 void qjackctlPatchbayForm::addOSocket (void)
@@ -718,6 +714,13 @@ void qjackctlPatchbayForm::disconnectAll (void)
 }
 
 
+// Expand all socket items.
+void qjackctlPatchbayForm::expandAll (void)
+{
+	m_pPatchbay->expandAll();
+}
+
+
 // Keyboard event handler.
 void qjackctlPatchbayForm::keyPressEvent ( QKeyEvent *pKeyEvent )
 {
