@@ -1,7 +1,7 @@
 // qjackctlPatchbayForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -60,9 +60,6 @@ public:
 	void setRecentPatchbays(const QStringList& patchbays);
 	void updateRecentPatchbays();
 
-	void setJackClient(jack_client_t * pJackClient);
-	void setAlsaSeq(snd_seq_t *pAlsaSeq);
-
 public slots:
 
 	void newPatchbay();
@@ -89,6 +86,8 @@ public slots:
 	void disconnectSelected();
 	void disconnectAll();
 
+	void expandAll();
+
 	void contentsChanged();
 
 	void refreshForm();
