@@ -1,7 +1,7 @@
 // qjackctlSetup.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -66,17 +66,16 @@ void qjackctlSetup::loadSetup (void)
 	bSingleton               = m_settings.value("/Singleton", true).toBool();
 //	sServerName              = m_settings.value("/ServerName").toString();
 	bStartJack               = m_settings.value("/StartJack", false).toBool();
-	bStartupScript           = m_settings.value("/StartupScript", true).toBool();
-	sStartupScriptShell      = m_settings.value("/StartupScriptShell", "artsshell -q terminate").toString();
+	bStartupScript           = m_settings.value("/StartupScript", false).toBool();
+	sStartupScriptShell      = m_settings.value("/StartupScriptShell").toString();
 	bPostStartupScript       = m_settings.value("/PostStartupScript", false).toBool();
 	sPostStartupScriptShell  = m_settings.value("/PostStartupScriptShell").toString();
 	bShutdownScript          = m_settings.value("/ShutdownScript", false).toBool();
 	sShutdownScriptShell     = m_settings.value("/ShutdownScriptShell").toString();
-	bPostShutdownScript      = m_settings.value("/PostShutdownScript", true).toBool();
-	sPostShutdownScriptShell = m_settings.value("/PostShutdownScriptShell", "killall jackd").toString();
+	bPostShutdownScript      = m_settings.value("/PostShutdownScript", false).toBool();
+	sPostShutdownScriptShell = m_settings.value("/PostShutdownScriptShell").toString();
 	bStdoutCapture           = m_settings.value("/StdoutCapture", true).toBool();
 	sXrunRegex               = m_settings.value("/XrunRegex", "xrun of at least ([0-9|\\.]+) msecs").toString();
-	bXrunIgnoreFirst         = m_settings.value("/XrunIgnoreFirst", false).toBool();
 	bActivePatchbay          = m_settings.value("/ActivePatchbay", false).toBool();
 	sActivePatchbayPath      = m_settings.value("/ActivePatchbayPath").toString();
 #ifdef CONFIG_AUTO_REFRESH
@@ -120,6 +119,9 @@ void qjackctlSetup::loadSetup (void)
 
 	m_settings.beginGroup("/Defaults");
 	sPatchbayPath = m_settings.value("/PatchbayPath").toString();
+	iMessagesStatusTabPage = m_settings.value("/MessagesStatusTabPage", 0).toInt();
+	iConnectionsTabPage = m_settings.value("/ConnectionsTabPage", 0).toInt();
+	iSessionSaveType = m_settings.value("/SessionSaveType", 0).toInt();
 	m_settings.endGroup();
 
 	// Load recent patchbay list...
@@ -133,6 +135,18 @@ void qjackctlSetup::loadSetup (void)
 		patchbays.append(sItem);
 	}
 	m_settings.endGroup();
+
+	// Load recent session directory list...
+	m_settings.beginGroup("/SessionDirs");
+	sPrefix = "/SessionDir%1";
+	i = 0;
+	for (;;) {
+		QString sItem = m_settings.value(sPrefix.arg(++i)).toString();
+		if (sItem.isEmpty())
+			break;
+		sessionDirs.append(sItem);
+	}
+	m_settings.endGroup();
 }
 
 
@@ -171,7 +185,6 @@ void qjackctlSetup::saveSetup (void)
 	m_settings.setValue("/PostShutdownScriptShell", sPostShutdownScriptShell);
 	m_settings.setValue("/StdoutCapture",           bStdoutCapture);
 	m_settings.setValue("/XrunRegex",               sXrunRegex);
-	m_settings.setValue("/XrunIgnoreFirst",         bXrunIgnoreFirst);
 	m_settings.setValue("/ActivePatchbay",          bActivePatchbay);
 	m_settings.setValue("/ActivePatchbayPath",      sActivePatchbayPath);
 #ifdef CONFIG_AUTO_REFRESH
@@ -215,6 +228,9 @@ void qjackctlSetup::saveSetup (void)
 
 	m_settings.beginGroup("/Defaults");
 	m_settings.setValue("/PatchbayPath", sPatchbayPath);
+	m_settings.setValue("/MessagesStatusTabPage", iMessagesStatusTabPage);
+	m_settings.setValue("/ConnectionsTabPage", iConnectionsTabPage);
+	m_settings.setValue("/SessionSaveType", iSessionSaveType);
 	m_settings.endGroup();
 
 	// Save patchbay list...
@@ -229,6 +245,18 @@ void qjackctlSetup::saveSetup (void)
 		m_settings.remove(sPrefix.arg(i));
 	m_settings.endGroup();
 
+	// Save session directory list...
+	m_settings.beginGroup("/SessionDirs");
+	sPrefix = "/SessionDir%1";
+	i = 0;
+	QStringListIterator iter3(sessionDirs);
+	while (iter3.hasNext())
+		m_settings.setValue(sPrefix.arg(++i), iter3.next());
+	// Cleanup old entries, if any...
+	while (!m_settings.value(sPrefix.arg(++i)).toString().isEmpty())
+		m_settings.remove(sPrefix.arg(i));
+	m_settings.endGroup();
+
 	// Commit all changes to disk.
 	m_settings.sync();
 }
@@ -314,6 +342,7 @@ bool qjackctlSetup::loadPreset ( qjackctlPreset& preset, const QString& sPreset
 
 	m_settings.beginGroup("/Settings" + sSuffix);
 	preset.sServer      = m_settings.value("/Server", "jackd").toString();
+	preset.sServerName  = m_settings.value("/ServerName").toString();
 	preset.bRealtime    = m_settings.value("/Realtime", true).toBool();
 	preset.bSoftMode    = m_settings.value("/SoftMode", false).toBool();
 	preset.bMonitor     = m_settings.value("/Monitor", false).toBool();
@@ -369,6 +398,7 @@ bool qjackctlSetup::savePreset ( qjackctlPreset& preset, const QString& sPreset
 
 	m_settings.beginGroup("/Settings" + sSuffix);
 	m_settings.setValue("/Server",      preset.sServer);
+	m_settings.setValue("/ServerName",  preset.sServerName);
 	m_settings.setValue("/Realtime",    preset.bRealtime);
 	m_settings.setValue("/SoftMode",    preset.bSoftMode);
 	m_settings.setValue("/Monitor",     preset.bMonitor);
@@ -632,41 +662,40 @@ void qjackctlSetup::saveSplitterSizes ( QSplitter *pSplitter )
 //---------------------------------------------------------------------------
 // Widget geometry persistence helper methods.
 
-void qjackctlSetup::loadWidgetGeometry ( QWidget *pWidget, bool bMinimized )
+void qjackctlSetup::loadWidgetGeometry ( QWidget *pWidget, bool bVisible )
 {
 	// Try to restore old form window positioning.
 	if (pWidget) {
-		QPoint fpos;
-		QSize  fsize;
-		bool bVisible;
+		QPoint wpos;
+		QSize  wsize;
 		m_settings.beginGroup("/Geometry/" + pWidget->objectName());
-		fpos.setX(m_settings.value("/x", -1).toInt());
-		fpos.setY(m_settings.value("/y", -1).toInt());
-		fsize.setWidth(m_settings.value("/width", -1).toInt());
-		fsize.setHeight(m_settings.value("/height", -1).toInt());
-		bVisible = m_settings.value("/visible", false).toBool();
+		wpos.setX(m_settings.value("/x", -1).toInt());
+		wpos.setY(m_settings.value("/y", -1).toInt());
+		wsize.setWidth(m_settings.value("/width", -1).toInt());
+		wsize.setHeight(m_settings.value("/height", -1).toInt());
+		if (!bVisible) bVisible = m_settings.value("/visible", false).toBool();
 		m_settings.endGroup();
-		new qjackctlDelayedSetup(pWidget, fpos, fsize, bVisible && !bMinimized,
-			(bDelayedSetup ? 1000 : 0));
+		new qjackctlDelayedSetup(pWidget, wpos, wsize,
+			bVisible && !bStartMinimized, (bDelayedSetup ? 1000 : 0));
 	}
 }
 
 
-void qjackctlSetup::saveWidgetGeometry ( QWidget *pWidget, bool bMinimized )
+void qjackctlSetup::saveWidgetGeometry ( QWidget *pWidget, bool bVisible )
 {
 	// Try to save form window position...
 	// (due to X11 window managers ideossincrasies, we better
 	// only save the form geometry while its up and visible)
 	if (pWidget) {
 		m_settings.beginGroup("/Geometry/" + pWidget->objectName());
-		bool bVisible = pWidget->isVisible();
-		const QPoint& fpos  = pWidget->pos();
-		const QSize&  fsize = pWidget->size();
-		m_settings.setValue("/x", fpos.x());
-		m_settings.setValue("/y", fpos.y());
-		m_settings.setValue("/width", fsize.width());
-		m_settings.setValue("/height", fsize.height());
-		m_settings.setValue("/visible", bVisible && !bMinimized);
+		const QPoint& wpos  = pWidget->pos();
+		const QSize&  wsize = pWidget->size();
+		if (!bVisible) bVisible = pWidget->isVisible();
+		m_settings.setValue("/x", wpos.x());
+		m_settings.setValue("/y", wpos.y());
+		m_settings.setValue("/width", wsize.width());
+		m_settings.setValue("/height", wsize.height());
+		m_settings.setValue("/visible", bVisible && !bStartMinimized);
 		m_settings.endGroup();
 	}
 }
@@ -703,6 +732,7 @@ void qjackctlDelayedSetup::setup (void)
 		if (m_bVisible)
 			m_pWidget->show();
 	}
+
 	deleteLater();
 }
 
