@@ -1,7 +1,7 @@
 // qjackctlSetup.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -47,6 +47,7 @@ class QSplitter;
 struct qjackctlPreset
 {
 	QString sServer;
+	QString sServerName;
 	bool    bRealtime;
 	bool    bSoftMode;
 	bool    bMonitor;
@@ -126,7 +127,6 @@ public:
 	QString sPostShutdownScriptShell;
 	bool    bStdoutCapture;
 	QString sXrunRegex;
-	bool    bXrunIgnoreFirst;
 	bool    bActivePatchbay;
 	QString sActivePatchbayPath;
 #ifdef CONFIG_AUTO_REFRESH
@@ -172,6 +172,16 @@ public:
 	// Recent patchbay listing.
 	QStringList patchbays;
 
+	// Recent session directories.
+	QStringList sessionDirs;
+
+	// Last open tab page...
+	int iMessagesStatusTabPage;
+	int iConnectionsTabPage;
+
+	// Last session save type...
+	int iSessionSaveType;
+	
 	// Aliases containers.
 	qjackctlConnectAlias aliasAudioOutputs;
 	qjackctlConnectAlias aliasAudioInputs;
@@ -197,8 +207,8 @@ public:
 	void saveSplitterSizes(QSplitter *pSplitter);
 
 	// Widget geometry persistence helper prototypes.
-	void saveWidgetGeometry(QWidget *pWidget, bool bMinimized = false);
-	void loadWidgetGeometry(QWidget *pWidget, bool bMinimized = false);
+	void saveWidgetGeometry(QWidget *pWidget, bool bVisible = false);
+	void loadWidgetGeometry(QWidget *pWidget, bool bVisible = false);
 
 private:
 
